#
# spec file for package drumstick
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2005-2010 Pedro Lopez-Cabanillas <plcl@users.sourceforge.net>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           drumstick
Version:        2.10.0
Release:        1.1
Summary:        MIDI Sequencer C++ Library Bindings
License:        GPL-2.0-or-later AND GPL-3.0-or-later
URL:            https://drumstick.sourceforge.io/
Source:         https://sourceforge.net/projects/drumstick/files/%{version}/%{name}-%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  shared-mime-info
BuildRequires:  cmake(Qt6Concurrent)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6UiPlugin)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(sonivox)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpulse-simple)

%description
This package includes test and example programs for drumstick libraries.

%lang_package

%package mimetypes
Summary:        MIDI Sequencer C++ Library MIME types
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Conflicts:      libdrumstick-file1

%description mimetypes
This package includes a mimetype for Cakewalk project files.

%package -n libdrumstick-rt2
Summary:        MIDI Sequencer C++ Library
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Requires:       libdrumstick-rt2-plugins

%description -n libdrumstick-rt2
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This library includes a class for managing realtime MIDI input/output backends.

%package -n libdrumstick-rt2-plugins
Summary:        MIDI Sequencer C++ Library
License:        Apache-2.0 AND GPL-2.0-or-later AND GPL-3.0-or-later

%description -n libdrumstick-rt2-plugins
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This package contains input/output plugins for libdrumstick-rt2.

%package -n libdrumstick-file2
Summary:        MIDI Sequencer C++ Library
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Recommends:     drumstick-mimetypes

%description -n libdrumstick-file2
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This library includes classes providing file input and output in formats
commonly used by MIDI programs. Currently, SMF (standard MIDI file)
read/write and WRK (Cakewalk) file read are supported. This library does not
depend on ALSA.

%package -n libdrumstick-alsa2
Summary:        MIDI Sequencer C++ Library
License:        GPL-2.0-or-later AND GPL-3.0-or-later

%description -n libdrumstick-alsa2
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This library includes the ALSA Sequencer library classes, providing MIDI
recording and playback functionality to C++/Qt5 programs.

%package -n libdrumstick-widgets2
Summary:        MIDI Sequencer C++ Library
License:        GPL-2.0-or-later AND GPL-3.0-or-later
# for the lang_package
Provides:       libdrumstick-widgets = %{version}

%description -n libdrumstick-widgets2
MIDI Sequencer C++ Library Bindings for Qt5 and ALSA.
This library includes the Widgets library, providing
GUI, MIDI related, components for C++/Qt5 programs.

%lang_package -n libdrumstick-widgets

%package -n libdrumstick-devel
Summary:        Development package for the libdrumstick library
License:        GPL-2.0-or-later AND GPL-3.0-or-later
Requires:       alsa-devel
Requires:       glibc-devel
Requires:       libdrumstick-alsa2 = %{version}
Requires:       libdrumstick-file2 = %{version}
Requires:       libdrumstick-rt2 = %{version}
Requires:       libdrumstick-widgets2 = %{version}
Requires:       libstdc++-devel
Requires:       cmake(Qt6Core)

%description -n libdrumstick-devel
This package contains the files needed to compile programs that use the
libdrumstick libraries.

%package -n libdrumstick-doc
Summary:        Development documentation package for the drumstick libraries
License:        GPL-2.0-or-later AND GPL-3.0-or-later
BuildArch:      noarch

%description -n libdrumstick-doc
This package contains the developer's documentation of the drumstick libraries.

%prep
%autosetup -p1

# Update obsolete config file
doxygen -u Doxyfile.in
sed -i 's#%{_includedir}/QtCore#%{_includedir}/qt6/QtCore#' Doxyfile.in
sed -i 's#%{_includedir}/QtGui#%{_includedir}/qt6/QtGui#' Doxyfile.in

%build
%cmake_qt6 -DSTATIC_DRUMSTICK=0

%qt6_build

cmake --build %{__qt6_builddir} -t doxygen

%install
%qt6_install

%ldconfig_scriptlets
%ldconfig_scriptlets -n libdrumstick-alsa2
%ldconfig_scriptlets -n libdrumstick-file2
%ldconfig_scriptlets -n libdrumstick-rt2
%ldconfig_scriptlets -n libdrumstick-widgets2

%files
%license COPYING
%doc AUTHORS NEWS TODO ChangeLog
%{_bindir}/drumstick-*
%{_datadir}/applications/net.sourceforge.drumstick-*.desktop
%{_datadir}/icons/hicolor/*/apps/drumstick.png
%{_datadir}/icons/hicolor/scalable/apps/drumstick.svgz
%{_datadir}/metainfo/net.sourceforge.drumstick-*.xml
%{_mandir}/man1/drumstick-*.1%{?ext_man}

%files lang
%license COPYING
%dir %{_datadir}/drumstick
%{_datadir}/drumstick/drumstick-drumgrid_*.qm
%{_datadir}/drumstick/drumstick-guiplayer_*.qm
%{_datadir}/drumstick/drumstick-vpiano_*.qm

%files mimetypes
%{_datadir}/mime/packages/drumstick.xml

%files -n libdrumstick-rt2
%license COPYING
%{_libdir}/libdrumstick-rt.so.*

%files -n libdrumstick-rt2-plugins
%license COPYING
%{_libdir}/drumstick2/

%files -n libdrumstick-file2
%license COPYING
%{_libdir}/libdrumstick-file.so.*

%files -n libdrumstick-alsa2
%license COPYING
%{_libdir}/libdrumstick-alsa.so.*

%files -n libdrumstick-widgets2
%license COPYING
%{_libdir}/libdrumstick-widgets.so.*

%files -n libdrumstick-widgets-lang
%license COPYING
%dir %{_datadir}/drumstick
%{_datadir}/drumstick/drumstick-widgets_*.qm

%files -n libdrumstick-devel
%license COPYING
%dir %{_includedir}/drumstick
%{_includedir}/drumstick.h
%{_includedir}/drumstick/*.h
%{_libdir}/libdrumstick-alsa.so
%{_libdir}/libdrumstick-file.so
%{_libdir}/libdrumstick-rt.so
%{_libdir}/libdrumstick-widgets.so
%{_libdir}/pkgconfig/drumstick-*.pc
%{_libdir}/cmake/drumstick
%dir %{_qt6_pluginsdir}/designer
%{_qt6_pluginsdir}/designer/libdrumstick-vpiano-plugin.so

%files -n libdrumstick-doc
%doc build/doc/html/*

%changelog
* Sun Feb  2 2025 Christophe Marin <christophe@krop.fr>
- Update to 2.10.0
  * RT: FluidSynth backend, using "audio.jack.autoconnect" when
    the audio driver is "jack"
  * ALSA: emitted signal with invalid pointer
  * RT, Widgets: issues with the new reverb/chorus fluidsynth
    settings
  * ALSA: new QDebug output operator accepting SequencerEvent
    instances
  * Widgets: revised user interface for the fluidsynth settings
  * fixed backendmanager usage in vpiano
* Mon Oct 14 2024 Christophe Marin <christophe@krop.fr>
- Update to 2.9.1
  RT library:
  * initialization of PipeWire in the FluidSynth backend.
  * fix for #25: FluidSynth backend, ability to configure chorus
    and reverb parameters.
  * fix for #24: FluidSynth backend, ability to set several
    soundfonts.
  Widgets library:
  * fix for #25: FluidSynth settings dialog, configuration of
    chorus and reverb.
  * fix for #24: FluidSynth settings dialog, select several
    soundfonts.
* Thu Feb  1 2024 Christophe Marin <christophe@krop.fr>
- Update to 2.9.0
  * new SettingsFactory public static methods: fileName() and
    format() (gh#pedrolcl/drumstick#15)
  * new slot writeSettings() for some backends: Sonivox,
    FluidSynth, Network (gh#pedrolcl/drumstick#16)
  * Building with Qt6 by default.
  * For Qt5 compatibility, a new option USE_QT5 must be set.
  * Upgraded compiler/runtime requirements to C++17.
  * Upgraded CMake requirement to 3.16
* Tue Oct 24 2023 Christophe Marin <christophe@krop.fr>
- Update to 2.8.1
  * CMake config check to avoid mixing Qt6 with Qt5
  * File: Improved RMID file support
    Extract DLS embedded data
    Decode DLS instrument names
    New mime type
  * RT Sonivox backend: enabled DLS file loading
  * Widgets: Sonivox configuration dialog updated
  * Chinese translation updated. Thanks to Hycinth
  * CMake config check to avoid mixing Qt6 with Qt5
  * Widgets: fixed compiler definitions, removed object headers
    duplicity
  * dumprmi utility: fixed QScopedPointer template for arrays
  * Updated doxygen settings for Doxygen 1.9.5
  * Widgets: clip note children (labels)
  * Unit tests: conditionally run the ALSA test and run the
    Widgets test using the QPA platform "offscreen"
  * ALSA: added assignment operators for sysex and text events
  * Fix for ticket #48: SMF Parser does not report enough errors
  * Implemented change soundfont function for the SonivoxEAS
    backend.
* Mon Oct  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.7.2
  * Italian translation update
  * FluidSynth backend should honor its default soundfont.
* Thu Aug 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.7.1
  * Improved the sonivox detection when building drumstick
  * Fixed underlinking in some RT backends
* Fri Aug 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.7.0. Check the ChangeLog file for the full list of
  changes:
  * Utils: vpiano uses the subscript octave designation option
  * Drumstick::ALSA revision, registering SequencerEvent
    with qMetaType
  * Drumstick::Widgets - fixed piano designer plugin to show
    more properties
  * fixed fluidsynth backend to support channel pressure and
    key pressure MIDI events
  * fluidsynth backend files and classes renamed with more
    specific names.
  * removed sonivox library sources from the source tree
* Sat Jul 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.6.1
  * Fixed generated pkgconfig files
  * Fix the wrong icon in KDE+Wayland
  * Fixed another issue with installation library dir
* Mon May  2 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.6.0
  * Widgets: Fluidsynth soundfonts dialog, updated filters
  * RT: Fluidsynth backend initialization: failure report for
    invalid soundfonts
  * Utils: fixed loading translations, program names and messages
  * cmake buildsystem: run qt::lupdate after building targets
  * Widgets: pianokeybd internal raw computer keyboard input
    processing
  * Utils: vpiano gets and uses a new raw keyboard menu option
  * Widgets: fixed pianokeybd's touchscreen input on Linux,
    including X11 and Wayland.
  * Utils: vpiano new menu options to allow enabling keyboard,
    mouse and touchscreen input.
  * Widgets: pianokeybd has 2 new functions, setUsingNativeFilter()
    and isUsingNativeFilter().
  * Utils: vpiano note labels font stability fix.
* Tue Jan 25 2022 Wolfgang Bauer <wbauer@tmo.at>
- Enable fluidsynth support on Leap 15.4 too, fluidsynth was
  updated
* Mon Jan  3 2022 Giordano Boschetti <geekosdaw@gmail.com>
- Update to 2.5.0
  * Documentation/deprecation of Drumstick::File functions affected by QTextCodec
  * Documented new build options and Qt6Core5Compat dependency for Drumstick::File
  * Raised macOS deployment target to 10.13 (High Sierra)
  * RT, VPiano: Fixed ALSA backend, enable empty input connection.
  * New build options: BUILD_ALSA, BUILD_FILE, BUILD_RT, BUILD_WIDGETS
  * Reduced usage of Qt6Core5Compat to the minimum
  * Widgets: changed the white keys background picture depending on the key background color
  * VPiano: new option to display inverted key colors
  * fix for ticket #37: WRK format markers are not decoded
  * Widgets library Swedish translation updated. Thanks to Magnus Johansson.
  * Widgets library Czech translation updated. Thanks to Pavel Fric.
* Wed Oct  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.4.0
  * RIFF RMID file support. New utility dumprmi, and guiplayer updated.
  * Fixed missing library version functions in File and RT libs
  * Enabled by default the internal reverb on macOS DLS Synth
  * Avoid hardcoded font family name in vpiano
* Wed Aug 18 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.3.1
  * updated documentation
  * Fixed WRK file processing in guiplayer utility
  * Fixed SMF system exclusive event write method
* Wed Jun 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.3.0. Changes since 2.2.0:
  * experimental cmake support for building with Qt6
  * New options: USE_PULSEAUDIO, USE_FLUIDSYNTH, USE_NETWORK
  * Revised CMake buildsystem and documents
  * Widgets: Fixed touch events - checked pressure capability
* Thu May 20 2021 Wolfgang Bauer <wbauer@tmo.at>
- Build without fluidsynth on Leap 15, the included one is too old
* Sat May 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.2.0
  * New option BUILD_UTILS
  * FluidSynth backend: initialization moved to a background thread
  * Retrieve dynamically the audio driver names for using in
    configuration dialog
  * new QWrk class signals with a QByteArray parameter
    instead of QString
  * Standarization: MIDI texts/lyrics encoding defaults to Latin1
  * removed warnings when buiding with Qt >= 5.15
  * * French and German translations updated
* Thu Apr 22 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.1.1. Fixes:
  * highlight color is wrong unless velocity tint is active
  * error parsing a wrk file
  * fixed stop playback, removed Overture mimetype from desktop
    file
  See the installed ChangeLog file for other changes.
* Tue Jan 12 2021 Wolfgang Bauer <wbauer@tmo.at>
- Split out the Cakewalk mimetype into a seperate package, it
  breaks co-installability of several library versions
* Sun Jan 10 2021 Wolfgang Bauer <wbauer@tmo.at>
- Update to 2.0.0
  * New features:
    + Code and build systems modernization
    + Namespaces reorganization
    + New library: drumstick-widgets providing a PianoKeybd widget
    plugin for Qt Creator and Qt Designer
    + New unit tests, for drumstick-widgets and wrk files
    + translations for drumstick-widgets and utils
    + License GPLv3 for all components
    + Each library provides at runtime its version in string format
    + Every program reports the linked library names/versions in
    the about box
    + Documentation of the new API for drumstick-widgets
    + drumstick-rt: plugins versioning, allowing runtime
    coexistence between plugins of drumstick-1 and drumstick-2.
  * Fixes:
    + drumstick-file: OVE file support removal
    + New library drumstick-widgets
    + Same names for ALSA Sequencer clients of two hw USB
    controllers
    + regression: drumstick-guiplayer doesn't remember saved MIDI
    output device
    + Better rendering of note names in piano keyboard widget
    + drumstick-vpiano: fixed SonivoxEAS saved connection string
- Use %%cmake instead of %%cmake_kf5 and remove kf5-filesystem
  BuildRequires, the package doesn't use KDE Frameworks at all
* Sun Oct 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.1.3
  * IPv6 support added
  * Avoid endless loops on unexpected end of input.
  * Generate SMFError when the parser finds unexpected end of input.
  * general cleanups and bringing back the fluidsynth backend
  * migration to full GNUInstallDirs support
  * modernization started of the CMake build system
  * Library includes reorganization
  * Fixed drumstick-file unit test
  * Custom commandline parser replaced by standard Qt5 QCommandLineParser
  * fixed spurious error message for ALSA input
- Drop Dont-use-QOverload.patch. No longer needed.
- Update the libdrumstick-rt-plugins license tag, eassynth contains
  Apache-2.0 files.
* Tue Dec 18 2018 wbauer@tmo.at
- Add Dont-use-QOverload.patch to make it build on Leap 42.3
* Tue Dec 18 2018 wbauer@tmo.at
- Update to 1.1.2
  * Fix for ticket #13 - some macOS input events lost
  * Added some bundle metadata for macOS
  * Solution for ticket #8: Path for plugins hardcoded
- Add pkgconfig(libpulse-simple) BuildRequires to enable building
  of libdrumstick-rt-eassynth.so (boo#1119734)
- Move rt input/output plugins to a separate
  libdrumstick-rt-plugins package that's required by
  libdrumstick-rt1
* Fri May 25 2018 christophe@krop.fr
- Update to 1.1.1
  * fixed tab order on forms
  * rt: fixed pitch bend events on several output backends
  * removed ALSA/Linux dependency where possible.
  * disabled fluidsynth output driver
- Split libdrumstick-rt from the main package.
* Mon Dec 18 2017 christophe@krop.fr
- Update to 1.1.0
  * guiplayer accepts a single file argument in the command line:
    mid, kar, wrk and ove
  * documentation updated
  Check the installed ChangeLog file for the complete changelog.
- Drop gcc6-fix.patch. Merged upstream.
* Fri Jun 17 2016 jengelh@inai.de
- Drop archaic sections, set rpm groups
* Fri Jun 17 2016 wbauer@tmo.at
- The devel package requires libQt5Core-devel now, not libqt4-devel
* Fri Jun 17 2016 wbauer@tmo.at
- Add gcc6-fix.patch to fix build with gcc6
* Wed Jun 15 2016 wbauer@tmo.at
- Use shared-mime-database macros (boo#979301)
* Tue Apr 12 2016 tittiatcoke@gmail.com
- Update to version 1.0.2
  * Qt5 port.
- Drop x11.diff. No longer required.
* Sun Nov 13 2011 alinm.elena@gmail.com
- fixed x11 failure to link in 12.1 added x11.diff patch
- moved to cmake_kde4 macro
* Thu Feb 17 2011 javier@opensuse.org
- switch to %%{?_smp_mflags}, remove additional optflags,
  clean package file list
* Wed Feb 16 2011 javier@opensuse.org
- fix package file list
* Wed Feb 16 2011 javier@opensuse.org
- copy package from home:plcl and clean spec a bit
